import { EchartsUI } from "@/components/EchartsUI";
import { initMapCountCtrl, renderTable } from "@/modules/count";
import { css } from "@linaria/core";
import { defineComponent } from "vue";

export default defineComponent(() => {
  const control = initMapCountCtrl();
  const { state } = control;

  return () => (
    <div class="p-20px space-y-20px">
      <div class="grid grid-cols-3 py-16px bg-white rounded text-center">
        {control.tabs.map((d) => {
          return (
            <div class={topTabCls}>
              <div class="text-[#333] text-22px font-500 mb-8px">
                {control.state.total[d.value]}
              </div>
              <div class="text-[#666] text-12px">{d.label}</div>
            </div>
          );
        })}
      </div>
      <div class="bg-white rounded text-center font-500 flow-root">
        <div class="grid grid-cols-3 leading-48px text-14px">
          {control.tabs.map((d) => {
            return (
              <div
                class={[mapTabCls, d.value === state.currType && "active"]}
                onClick={() => control.switchStatType(d.value)}
              >
                {d.label}
              </div>
            );
          })}
        </div>
        <EchartsUI.Map class="h-300px" data={state.currMapData} />
        <div class="m-15px text-center">{renderTable(control)}</div>
      </div>
    </div>
  );
});

const topTabCls = css`
  &:not(:first-child) {
    border-left: 1px solid #f1f1f1;
  }
`;

const mapTabCls = css`
  background-color: #f1f1f1;
  &.active {
    background-color: #fff;
  }
`;
