import { EchartsUI } from "@/components/EchartsUI";
import { initMapCountCtrl, renderTable } from "@/modules/count";
import { css } from "@linaria/core";
import { Select } from "ant-design-vue";
import { defineComponent } from "vue";

export default defineComponent({
  setup() {
    const control = initMapCountCtrl();
    const { tabs, state } = control;

    return () => (
      <div class={rootCls}>
        <section class="grid grid-cols-3">
          {tabs.map((d, i) => {
            return (
              <div class={tabItemCls} key={i}>
                <div class="text-0.2rem text-[#666]">{d.label}</div>
                <div class="text-0.4rem text-[#333] font-bold mt-0.1rem">
                  {state.total[d.value]}
                </div>
              </div>
            );
          })}
        </section>
        <section class="flex-1 h-0 flex flex-col p-0.3rem mt-0.3rem">
          <div>
            <Select
              class="w-2rem"
              options={tabs}
              value={state.currType}
              onChange={(v) => control.switchStatType(v as string)}
            ></Select>
          </div>
          <div class="flex-1 grid grid-cols-2 h-0">
            <EchartsUI.Map class data={state.currMapData} />
            <div class={tableCls}>{renderTable(control)}</div>
          </div>
        </section>
      </div>
    );
  },
});

const rootCls = css`
  @apply flex flex-col w-full h-full p-0.3rem;

  section {
    width: 100%;
    background-color: #fff;
    border-radius: 0.06rem;
  }
`;

const tabItemCls = css`
  @apply my-0.5rem px-0.5rem;

  &:not(:last-child) {
    border-right: 1px solid #efefef;
  }
`;

const tableCls = css`
  height: 100%;
  overflow-y: auto;
  text-align: left;
  th,
  td {
    padding: 0 0.2rem;
  }
  th {
    position: relative;
    &:not(:first-child) {
      &:before {
        position: absolute;
        display: block;
        content: "";
        height: 0.2rem;
        margin-left: -0.2rem;
        border-left: 1px solid #dbdbdb;
      }
    }
  }
`;
